if [ ! -e /etc/X11/fs/config ]
then
    /usr/bin/mkdir -p /etc/X11/fs
    /usr/bin/cp /etc/defaults/etc/X11/fs/config /etc/X11/fs/config
fi

